@@ -1,6 +1,7 @@
 from typing import Optional, Text, Dict, Any, Union
 
 import dill
+import base64
 
 from tfx import types
 from tfx.components.base import base_component
@@ -36,7 +37,7 @@ class SKLearnTransform(base_component.BaseComponent):
 
         dill_recurse_setting = dill.settings['recurse']
         dill.settings['recurse'] = True
-        preprocessor_pickle = dill.dumps(sklearn_pipeline).decode('utf-8')
+        preprocessor_pickle = base64.encodebytes(dill.dumps(sklearn_pipeline))
         dill.settings['recurse'] = dill_recurse_setting
 
         preprocessor_artifact = channel_utils.as_channel([stfxe_artifacts.SKLearnPrepocessor()])
